[Checkins] SVN: Products.CMFCore/trunk/Products/CMFCore/ - fixed some docstrings

Yvo Schubbe y.2008 at wcm-solutions.de
Fri Jul 18 07:08:23 EDT 2008


Log message for revision 88490:
  - fixed some docstrings

Changed:
  U   Products.CMFCore/trunk/Products/CMFCore/CHANGES.txt
  U   Products.CMFCore/trunk/Products/CMFCore/interfaces/_tools.py

-=-
Modified: Products.CMFCore/trunk/Products/CMFCore/CHANGES.txt
===================================================================
--- Products.CMFCore/trunk/Products/CMFCore/CHANGES.txt	2008-07-18 10:55:47 UTC (rev 88489)
+++ Products.CMFCore/trunk/Products/CMFCore/CHANGES.txt	2008-07-18 11:08:23 UTC (rev 88490)
@@ -2,6 +2,11 @@
 
   Products.CMFCore 2.2.0 (unreleased)
 
+    - interfaces: Fixed some docstrings.
+      There is no IActionInformation. ActionInformation is an old action class
+      that implements IAction, non-persistent IActionInfo objects adapt action
+      objects to a given context.
+
     - FSSTXMethod: Fixed Zope 2.12 compatibility.
       zope.structuredtext is now used instead of StructuredText.
 

Modified: Products.CMFCore/trunk/Products/CMFCore/interfaces/_tools.py
===================================================================
--- Products.CMFCore/trunk/Products/CMFCore/interfaces/_tools.py	2008-07-18 10:55:47 UTC (rev 88489)
+++ Products.CMFCore/trunk/Products/CMFCore/interfaces/_tools.py	2008-07-18 11:08:23 UTC (rev 88490)
@@ -90,7 +90,7 @@
         """ Map actions available to the user by category.
 
         o Returned mapping will have category IDs as keys, and sequences
           of IActionInformation objects as the corresponding values for each
           category.
 
         o Categories may be arbitrarily extended.
@@ -105,9 +105,9 @@
     """
 
     def listActions(info=None, object=None):
-        """ List known action informations.
+        """ List known actions.
 
-        o Return a sequence of IActionInformation intances.
+        o Return a sequence of action objects.
 
         o Both the 'object' and the 'info' arguments are deprecated and
           ignored (use 'listActionInfos' to filter actions by context).
@@ -115,7 +115,7 @@
 
     def listActionInfos(action_chain=None, object=None, check_visibility=True,
                         check_permissions=True, check_condition=True, max=None):
         """ Return a sequence of IActionInformation matching the given criteria.
 
         o 'action_chain' is a sequence of one or more action paths
           (e.g. 'object/view');  each path is formatted as
@@ -142,7 +142,7 @@
 
     def getActionInfo(action_chain, object=None, check_visibility=False,
                       check_condition=False):
         """ Return the first IActionInformation matching the given criteria.
 
         o If no action is found matching the criteria, raise ValueError.
 
@@ -168,7 +168,7 @@
     """
 
     def listActions():
-        """ Return a sequence of IActionInformation defined by this category
+        """ Return a sequence of IAction objects defined by this category.
 
         o Include actions defined by subcategories.
 
@@ -183,7 +183,7 @@
 
     def getInfoData():
         """ Return a lazy mapping of the data needed to create an
-            IActionInformation.
+            IActionInfo object.
 
         o Returned value is actually a tuple, '(lazy_map, lazy_keys)'.
 
@@ -1846,9 +1846,9 @@
         """
 
     def listObjectActions(info):
-        """ Return a sequence of IActionInformation defining workflow actions.
+        """ Return a sequence of workflow action objects.
 
-        o 'info' is an ObjectActionInformation structure. XXX?
+        o 'info' is an OAI (ObjectActionInformation ?) structure.
 
         o Returned actions are relevant to 'info.content' (this method is
           called only when this workflow is applicable to 'info.content').
@@ -1859,9 +1859,9 @@
         """
 
     def listGlobalActions(info):
-        """ Return a sequence of IActionInformation defining workflow actions.
+        """ Return a sequence of workflow action objects.
 
-        o 'info' is an ObjectActionInformation structure. XXX?
+        o 'info' is an OAI (ObjectActionInformation ?) structure.
 
         o Returned actions are "global", i.e. relevant to the user and  the
           site, rather than to any particular content object (this method is
@@ -90,7 +90,7 @@
 
         o Returned mapping will have category IDs as keys, and sequences
-          of IActionInformation objects as the corresponding values for each
+          of IActionInfo objects as the corresponding values for each
           category.
 
@@ -115,7 +115,7 @@
     def listActionInfos(action_chain=None, object=None, check_visibility=True,
                         check_permissions=True, check_condition=True, max=None):
-        """ Return a sequence of IActionInformation matching the given criteria.
+        """ Return a sequence of IActionInfo objects matching given criteria.
 
         o 'action_chain' is a sequence of one or more action paths
@@ -142,7 +142,7 @@
     def getActionInfo(action_chain, object=None, check_visibility=False,
                       check_condition=False):
-        """ Return the first IActionInformation matching the given criteria.
+        """ Return the first IActionInfo object matching the given criteria.
 
         o If no action is found matching the criteria, raise ValueError.



More information about the Checkins mailing list